{% extends "base.html" %}

{% block title %}Add Users{% endblock %}

{% block content %}

    <main role="main" class="content">
	<div class="container">

    <form method="post" action="">
    {% csrf_token %}

    <div class="form-group">

        <div class="card generic-card">
            <div class="card-header generic-card-header">
                <h4>Invite Staff</h4>
            </div>
            <div class="card-body">
                <div class="form-group">
                    <label for="email">Enter the email address for the person you would like to invite</label>
                    <div class="row">
                        <div class="col-sm-6">
                            {{ invite_user_form.email }}
                        </div>
                    </div>
                </div>

                {% if sent is not None %}
                    <div class="alert alert-success alert-dismissible show fade" role="alert">
                        Email invitation sent
                        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                {% endif %}
            </div>
        </div>

    </div>

    <div class="form-group">
        <button type="submit" class="btn btn-secondary" name="invite_users" value="Add">Invite</button>
        <button type="submit" class="btn btn-secondary" name="cancel" formnovalidate value="Cancel">Done</button>
    </div>
    </form>

    </div>
    </main>

{% endblock %}
