# Generated by Django 2.2.4 on 2019-09-04 16:25

from django.db import migrations, models
import schools.models


class Migration(migrations.Migration):

    dependencies = [
        ('schools', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='school',
            name='account_expiry',
            field=models.DateField(blank=True, default=schools.models.expiry_plus_28_days),
        ),
    ]
